@@ -1,8 +1,8 @@
 
 package Module::Spec::V1;
-$Module::Spec::V1::VERSION = '0.5.1';
+$Module::Spec::V1::VERSION = '0.5.2';
 # ABSTRACT: Load modules based on specifications V1
-use 5.010001;
+use 5.012;
 
 # use strict;
 # use warnings;
@@ -295,6 +295,10 @@ sub croak {
 #pod
 #pod =back
 #pod
+#pod =head1 SEE ALSO
+#pod
+#pod L<Module::Runtime>
+#pod
 #pod =cut
 
 __END__
@@ -309,7 +313,7 @@ Module::Spec::V1 - Load modules based on specifications V1
 
 =head1 VERSION
 
-version 0.5.1
+version 0.5.2
 
 =head1 SYNOPSIS
 
@@ -446,6 +450,10 @@ Exceptions are not thrown from the perspective of the caller.
 
 =back
 
+=head1 SEE ALSO
+
+L<Module::Runtime>
+
 =head1 AUTHOR
 
 Adriano Ferreira <ferreira@cpan.org>
